==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Ocultar todos los mensajes del acompañante',
	'bouton_tout_compris_explication' => 'Si ya está familiarizado con SPIP, puede elegir ignorar todos los mensajes del acompañante; de lo contrario, cada mensaje puede cerrarse individualmente.',

	// C
	'c_accueil_bienvenue' => '¡Bienvenido/a @nom@!',
	'c_accueil_configurer_site' => 'Configurar su sitio',
	'c_accueil_configurer_site_texte' => 'Una de las primeras cosas que hay que hacer es darle un nombre a su sitio.
Ahora se llama «@nom@». Puede ver el nombre del sitio en la parte superior de esta página.
Puede modificarlo haciendo clic sobre él, así como atribuirle un logo o un eslogan.',
	'c_accueil_publication' => '¡y a publicar !',
	'c_accueil_publication_texte' => 'Para publicar una página, hay que crear un artículo.
		Para esto, es necesario crear al menos una sección. Lo puedes hacer por el menú «Edición», eligiendo la opción «Secciones».',
	'c_accueil_texte' => 'Acabas de entrar en el espacio privado de SPIP.',
	'c_accueil_texte_revenir' => 'Esta página muestra la actividad editorial reciente de su sitio.
Puede volver a esta página en cualquier momento haciendo clic en el icono de la casa, en la parte superior sobre su nombre.',
	'c_article_redaction' => 'El artículo está en curso de redacción',
	'c_article_redaction_redacteur' => 'El artículo está en curso de redacción',
	'c_article_redaction_redacteur_texte' => 'Para proponer su artículo a los administradores del sitio y a los demás redactores, modifique en el cuadro aquí al lado, «en curso de redacción» por «propuesto a la publicación».',
	'c_article_redaction_texte' => 'Para publicar este artículo en el sitio público, hay que cambiar su estatuto.
		En el cuadro aquí al lado, cambia «en curso de recacción» por «publicado en línea».',
	'c_articles_creer' => '¿Cómo crear un artículo?',
	'c_articles_creer_texte' => 'Sólo cuando exista una sección en su sitio podrá crear un artículo desde esta página.
Puede crear una sección desde el menú «Edición», y luego «Secciones».',
	'c_job' => 'Tareas a realizar…',
	'c_job_texte' => 'Esta página lista las próximas tareas de mantenimiento que debe efectuar SPIP. Estas tareas se ejecutan a intervalos regulares, o puntualmente para los procesamientos pesados que puedan solicitar los plugins, como el envío masivo de correos.',
	'c_rubrique_publier' => 'Cree un artículo',
	'c_rubrique_publier_texte' => 'Una sección sólo será visible en el sitio público una vez que contenga algo publicado, por ejemplo un artículo. 
Cree entonces un artículo. Lo puede hacer desde esta página, bajo la descripción de la sección.',
	'c_rubriques_creer' => '¡Cree la primer sección!',
	'c_rubriques_creer_texte' => 'Las secciones son la estructura de base del sitio; en cada una de ellas podrá crear artículos.
Comience por crear una primer sección.',
	'c_sites_creer' => '¿Cómo crear o importar un sitio?',
	'c_sites_creer_texte' => 'Sólo puede crear o importar un sitio desde esta página cuando exista una sección en el sitio.
Puede crearlo desde el menú «Edición», eligiendo la opción «Secciones».',

	// E
	'explication_activer_compagnon' => 'El compañero agrega comentarios a ciertas páginas del espacio privado de SPIP para ayudar a familiarizarse con SPIP. ¿Quiere activarlo?',
	'explication_reinitialiser_compagnon' => 'Los mensajes que una autora o autor ya ha visto no se vuelven a mostrar.
¿Quiere reiniciar estos mensajes?',

	// L
	'label_activer_compagnon' => '¿Activar el compañero?',
	'label_reinitialiser_compagnon' => '¿Reinicializar los mensajes del compañero?',

	// O
	'ok' => 'OK',
	'ok_bien' => '¡Bien!',
	'ok_jai_compris' => '¡He entendido!',
	'ok_merci' => 'Gracias',
	'ok_parfait' => '¡Perfecto!',

	// R
	'reinitialisation' => 'Reinicio',
	'reinitialisation_ok' => 'El reinicio se ha efectuado.',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sí, únicamente los que ya he leído.',
	'reinitialiser_tous' => 'Sí, sea cual sea el autor',

	// T
	'titre_compagnon' => 'El Compañero',
	'titre_page_configurer_compagnon' => 'Configurar el Compañero'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_tout_compris' => 'Ocultar todos los mensajes del acompañante',
	'bouton_tout_compris_explication' => 'Si ya está familiarizado con SPIP, puede elegir ignorar todos los mensajes del acompañante; de lo contrario, cada mensaje puede cerrarse individualmente.',

	// C
	'c_accueil_bienvenue' => '¡Bienvenido/a @nom@!',
	'c_accueil_configurer_site' => 'Configurar su sitio',
	'c_accueil_configurer_site_texte' => 'Una de las primeras cosas que hay que hacer es darle un nombre a su sitio.
Ahora se llama «@nom@». Puede ver el nombre del sitio en la parte superior de esta página.
Puede modificarlo haciendo clic sobre él, así como atribuirle un logo o un eslogan.',
	'c_accueil_publication' => '¡y a publicar !',
	'c_accueil_publication_texte' => 'Para publicar una página, hay que crear un artículo.
		Para esto, es necesario crear al menos una sección. Lo puedes hacer por el menú «Edición», eligiendo la opción «Secciones».',
	'c_accueil_texte' => 'Acabas de entrar en el espacio privado de SPIP.',
	'c_accueil_texte_revenir' => 'Esta página muestra la actividad editorial reciente de su sitio.
Puede volver a esta página en cualquier momento haciendo clic en el icono de la casa, en la parte superior sobre su nombre.',
	'c_article_redaction' => 'El artículo está en curso de redacción',
	'c_article_redaction_redacteur' => 'El artículo está en curso de redacción',
	'c_article_redaction_redacteur_texte' => 'Para proponer su artículo a los administradores del sitio y a los demás redactores, modifique en el cuadro aquí al lado, «en curso de redacción» por «propuesto a la publicación».',
	'c_article_redaction_texte' => 'Para publicar este artículo en el sitio público, hay que cambiar su estatuto.
		En el cuadro aquí al lado, cambia «en curso de recacción» por «publicado en línea».',
	'c_articles_creer' => '¿Cómo crear un artículo?',
	'c_articles_creer_texte' => 'Sólo cuando exista una sección en su sitio podrá crear un artículo desde esta página.
Puede crear una sección desde el menú «Edición», y luego «Secciones».',
	'c_job' => 'Tareas a realizar…',
	'c_job_texte' => 'Esta página lista las próximas tareas de mantenimiento que debe efectuar SPIP. Estas tareas se ejecutan a intervalos regulares, o puntualmente para los procesamientos pesados que puedan solicitar los plugins, como el envío masivo de correos.',
	'c_rubrique_publier' => 'Cree un artículo',
	'c_rubrique_publier_texte' => 'Una sección sólo será visible en el sitio público una vez que contenga algo publicado, por ejemplo un artículo. 
Cree entonces un artículo. Lo puede hacer desde esta página, bajo la descripción de la sección.',
	'c_rubriques_creer' => '¡Cree la primer sección!',
	'c_rubriques_creer_texte' => 'Las secciones son la estructura de base del sitio; en cada una de ellas podrá crear artículos.
Comience por crear una primer sección.',
	'c_sites_creer' => '¿Cómo crear o importar un sitio?',
	'c_sites_creer_texte' => 'Sólo puede crear o importar un sitio desde esta página cuando exista una sección en el sitio.
Puede crearlo desde el menú «Edición», eligiendo la opción «Secciones».',

	// E
	'explication_activer_compagnon' => 'El compañero agrega comentarios a ciertas páginas del espacio privado de SPIP para ayudar a familiarizarse con SPIP. ¿Quiere activarlo?',
	'explication_reinitialiser_compagnon' => 'Los mensajes que una autora o autor ya ha visto no se vuelven a mostrar.
¿Quiere reiniciar estos mensajes?',

	// L
	'label_activer_compagnon' => '¿Activar el compañero?',
	'label_reinitialiser_compagnon' => '¿Reinicializar los mensajes del compañero?',

	// O
	'ok' => 'OK',
	'ok_bien' => '¡Bien!',
	'ok_jai_compris' => '¡He entendido!',
	'ok_merci' => 'Gracias',
	'ok_parfait' => '¡Perfecto!',

	// R
	'reinitialisation' => 'Reinicio',
	'reinitialisation_ok' => 'El reinicio se ha efectuado.',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sí, únicamente los que ya he leído.',
	'reinitialiser_tous' => 'Sí, sea cual sea el autor',

	// T
	'titre_compagnon' => 'El Compañero',
	'titre_page_configurer_compagnon' => 'Configurar el Compañero',
];
